==> RsSmbv-4.80.0.9-py3-none-any.whl: RsSmbv/Implementations/Source_/Bb_/C2K_/Mstation_/Channel_/Spreading.py <==
from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Spreading:
	"""Spreading commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("spreading", core, parent)

	def get(self, stream=repcap.Stream.Default, channel=repcap.Channel.Default) -> int:
		"""[SOURce<HW>]:BB:C2K:MSTation<ST>:CHANnel<CH>:SPReading \n
		Queries the spreading factor of the channel. The spreading factor corresponds to the length of the employed Walsh code.
		The Walsh codes to be used are specified by the standard and cannot be chosen. For the traffic channels, this value is
		specific for the selected radio configuration. \n
			:param stream: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mstation')
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Channel')
			:return: spreading: integer Range: 0 to 255"""
		stream_cmd_val = self._base.get_repcap_cmd_value(stream, repcap.Stream)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:C2K:MSTation{stream_cmd_val}:CHANnel{channel_cmd_val}:SPReading?')
		return Conversions.str_to_int(response)

==> RsSmbv-4.80.0.12-py3-none-any.whl: RsSmbv/Implementations/Source_/Bb_/C2K_/Mstation_/Channel_/Spreading.py <==
from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Spreading:
	"""Spreading commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("spreading", core, parent)

	def get(self, stream=repcap.Stream.Default, channel=repcap.Channel.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:C2K:MSTation<ST>:CHANnel<CH>:SPReading \n
		Snippet: value: int = driver.source.bb.c2K.mstation.channel.spreading.get(stream = repcap.Stream.Default, channel = repcap.Channel.Default) \n
		Queries the spreading factor of the channel. The spreading factor corresponds to the length of the employed Walsh code.
		The Walsh codes to be used are specified by the standard and cannot be chosen. For the traffic channels, this value is
		specific for the selected radio configuration. \n
			:param stream: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mstation')
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Channel')
			:return: spreading: integer Range: 0 to 255"""
		stream_cmd_val = self._base.get_repcap_cmd_value(stream, repcap.Stream)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:C2K:MSTation{stream_cmd_val}:CHANnel{channel_cmd_val}:SPReading?')
		return Conversions.str_to_int(response)
